#[non_exhaustive]pub enum GitCliBackendError {
GitCommand {
source: Error,
program: OsString,
args: Vec<OsString>,
},
GitExitStatus {
status: ExitStatus,
},
InvalidUtf8 {
source: Utf8Error,
},
InvalidGitStatus {
entry: Vec<u8>,
},
InvalidRevParse {
output: Vec<u8>,
},
NoGitDirParent {
git_dir: PathBuf,
},
NoWorktreeForGitDir {
git_dir: PathBuf,
},
}Available on crate feature
git-cli only.Expand description
Errors returned by git-cli backend operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GitCommand
Executing a git command failed.
Fields
GitExitStatus
A git command returned a non-zero exit status.
Fields

status: ExitStatusThe exit status returned by the git command.
InvalidUtf8
Converting the output of a git command to UTF-8 failed.
InvalidGitStatus
An invalid status entry was encountered in the output of git status.
InvalidRevParse
An invalid rev-parse output was encountered.
NoGitDirParent
A path was expected to have a parent directory, but it did not.
NoWorktreeForGitDir
No worktree listed by Git matched the repository administrative directory.