GixBackendError

Enum GixBackendError 

#[non_exhaustive]
pub enum GixBackendError { Discover { path: PathBuf, source: Error, }, Open { path: PathBuf, source: Error, }, Status { worktree: PathBuf, source: Error, }, StatusIntoIter { worktree: PathBuf, source: Error, }, IterateStatus { worktree: PathBuf, source: Error, }, }
Available on crate feature git-gix only.
Errors returned by gix backend operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Discover

Searching for a Git repository failed.

Fields

path: PathBuf

The path that was being searched for a Git repository.

source: Error

The underlying error from gix.



Open

Opening a Git repository failed.

Fields

path: PathBuf

The path that was being opened as a Git repository.

source: Error

The underlying error from gix.



Status

Querying the status of a Git repository failed.

Fields

worktree: PathBuf

The worktree of the Git repository.

source: Error

The underlying error from gix.



StatusIntoIter

Converting the status of a Git repository into an iterator failed.

Fields

worktree: PathBuf

The worktree of the Git repository.

source: Error

The underlying error from gix.



IterateStatus

Iterating over the status of a Git repository failed.

Fields

worktree: PathBuf

The worktree of the Git repository.

source: Error

The underlying error from gix.