pub enum ModificationSafety {
Safe,
Unsafe(UnsafeModificationReason),
}Expand description
Whether modification of the queried target is considered safe under the
current --allow-* policy.
This type describes the safety of modifying the queried target after applying the configured policy.
Variants
Safe
Modification of the queried target is considered safe.
Unsafe(UnsafeModificationReason)
Modification of the queried target is considered unsafe.
Contains the reason the modification is considered unsafe.