ModifyGuardError

Enum ModifyGuardError 

#[non_exhaustive]
pub enum ModifyGuardError { NotARepository { path: PathBuf, }, RepositoryWithoutWorktree { path: PathBuf, }, InaccessiblePath { path: PathBuf, source: Error, }, PathNotFound { path: PathBuf, }, CanonicalizePath { path: PathBuf, source: Error, }, PathNotADirectory { path: PathBuf, }, PathNotAFile { path: PathBuf, }, ResolveAsWorktreeRelativePath { path: PathBuf, }, AmbiguousFilePath { wt_path: PathBuf, }, Backend { source: Box<dyn Error + Send + Sync + 'static>, }, }
Errors returned by vcs-modify-guard operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NotARepository

The specified path does not refer to a repository supported by the enabled backends.

Fields

path: PathBuf

The path that was rejected.



RepositoryWithoutWorktree

The specified path refers to a repository without a worktree, such as a Git bare repository.

Fields

path: PathBuf

The path that was rejected.



InaccessiblePath

The specified path could not be accessed.

Fields

path: PathBuf

The path that was rejected.

source: Error

The underlying I/O error.



PathNotFound

The specified path was not found.

Fields

path: PathBuf

The path that was rejected.



CanonicalizePath

The specified path could not be resolved to a canonical path.

Fields

path: PathBuf

The path that was rejected.

source: Error

The underlying I/O error.



PathNotADirectory

The specified path is not a directory.

Fields

path: PathBuf

The path that was rejected.



PathNotAFile

The specified path does not resolve to a file.

Fields

path: PathBuf

The path that was rejected.



ResolveAsWorktreeRelativePath

The specified path does not resolve to a valid path within the repository worktree.

Fields

path: PathBuf

The path that was rejected.



AmbiguousFilePath

The specified path does not resolve to a single file within the repository worktree.

Fields

wt_path: PathBuf

The path that was rejected.



Backend

VCS backend error.

Fields

source: Box<dyn Error + Send + Sync + 'static>

The underlying error returned by the VCS backend.