#[non_exhaustive]pub enum UnsafeModificationReason {
NoVcs,
Dirty {
worktree: PathBuf,
dirty_files: Vec<PathBuf>,
staged_files: Vec<PathBuf>,
},
Staged {
worktree: PathBuf,
staged_files: Vec<PathBuf>,
},
}Expand description
The reason modification of the queried target is considered unsafe under
the current --allow-* policy.
This type explains why ModificationSafety::Unsafe was returned.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoVcs
Modification is considered unsafe because no supported VCS repository was found for the queried target.
Dirty
Modification is considered unsafe because dirty files were found.
staged_files is non-empty only when staged changes also make the
modification unsafe.
Fields
Staged
Modification is considered unsafe because staged changes were found.