GitCliBackendError

Enum GitCliBackendError 

#[non_exhaustive]
pub enum GitCliBackendError { GitCommand { source: Error, program: OsString, args: Vec<OsString>, }, GitExitStatus { status: ExitStatus, }, InvalidUtf8 { source: Utf8Error, }, InvalidGitStatus { entry: Vec<u8>, }, InvalidRevParse { output: Vec<u8>, }, NoGitDirParent { git_dir: PathBuf, }, NoWorktreeForGitDir { git_dir: PathBuf, }, }
Available on crate feature git-cli only.
Errors returned by git-cli backend operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


GitCommand

Executing a git command failed.

Fields

source: Error

The underlying error from executing the git command.

program: OsString

The git program that was executed.

args: Vec<OsString>

The arguments passed to the git command.



GitExitStatus

A git command returned a non-zero exit status.

Fields

status: ExitStatus

The exit status returned by the git command.



InvalidUtf8

Converting the output of a git command to UTF-8 failed.

Fields

source: Utf8Error

The underlying error from converting the git command output to UTF-8.



InvalidGitStatus

An invalid status entry was encountered in the output of git status.

Fields

entry: Vec<u8>

The invalid status entry from the git status output.



InvalidRevParse

An invalid rev-parse output was encountered.

Fields

output: Vec<u8>

The invalid output from the git rev-parse command.



NoGitDirParent

A path was expected to have a parent directory, but it did not.

Fields

git_dir: PathBuf

The path that was expected to have a parent directory.



NoWorktreeForGitDir

No worktree listed by Git matched the repository administrative directory.

Fields

git_dir: PathBuf

The repository administrative directory that could not be mapped back to a worktree.