#[non_exhaustive]pub enum GixBackendError {
Discover {
path: PathBuf,
source: Error,
},
Open {
path: PathBuf,
source: Error,
},
Status {
worktree: PathBuf,
source: Error,
},
StatusIntoIter {
worktree: PathBuf,
source: Error,
},
IterateStatus {
worktree: PathBuf,
source: Error,
},
}Available on crate feature
git-gix only.Expand description
Errors returned by gix backend operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Discover
Searching for a Git repository failed.
Fields
Open
Opening a Git repository failed.
Fields
Status
Querying the status of a Git repository failed.
Fields
StatusIntoIter
Converting the status of a Git repository into an iterator failed.
Fields
IterateStatus
Iterating over the status of a Git repository failed.