#[non_exhaustive]pub enum ModifyGuardError {
NotARepository {
path: PathBuf,
},
RepositoryWithoutWorktree {
path: PathBuf,
},
InaccessiblePath {
path: PathBuf,
source: Error,
},
PathNotFound {
path: PathBuf,
},
CanonicalizePath {
path: PathBuf,
source: Error,
},
PathNotADirectory {
path: PathBuf,
},
PathNotAFile {
path: PathBuf,
},
ResolveAsWorktreeRelativePath {
path: PathBuf,
},
AmbiguousFilePath {
wt_path: PathBuf,
},
Backend {
source: Box<dyn Error + Send + Sync + 'static>,
},
}Expand description
Errors returned by vcs-modify-guard operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotARepository
The specified path does not refer to a repository supported by the enabled backends.
RepositoryWithoutWorktree
The specified path refers to a repository without a worktree, such as a Git bare repository.
InaccessiblePath
The specified path could not be accessed.
PathNotFound
The specified path was not found.
CanonicalizePath
The specified path could not be resolved to a canonical path.
PathNotADirectory
The specified path is not a directory.
PathNotAFile
The specified path does not resolve to a file.
ResolveAsWorktreeRelativePath
The specified path does not resolve to a valid path within the repository worktree.
AmbiguousFilePath
The specified path does not resolve to a single file within the repository worktree.
Backend
VCS backend error.