FileChange

Struct FileChange 

pub struct FileChange { /* private fields */ }
A file change within a repository.

Values of this type are returned by Repository::file_change and yielded by iterators over RepositoryChanges returned by Repository::repository_changes and Repository::path_changes.

Instances of this type always represent a dirty file, a staged file, or both. Dirty files have unstaged modifications or are untracked. Clean tracked files and files ignored by the VCS are not represented; Repository::file_change returns None for those cases.

The stored path is the worktree-relative path associated with this change in the VCS. It may refer to a tracked path that is no longer present in the worktree.

More than one predicate may return true for the same file. For example, a file may have staged changes and additional unstaged tracked modifications.

Implementations

Source

impl FileChange

pub fn wt_path(&self) -> &Path

Returns the worktree-relative path associated with this file change in the VCS.

This may refer to a tracked path that is no longer present in the worktree.

When this change is returned by Repository::file_change, the returned path may differ from the path passed to that method when the input reaches the same path through symlinks or other equivalent non-canonical forms.

pub fn is_dirty(&self) -> bool

Returns whether the file is dirty.

A dirty file has unstaged modifications or is untracked. Staged-only changes are not considered dirty.

pub fn is_staged(&self) -> bool

Returns whether the file has staged changes in the index.